pub fn transpile(component: &[u8], opts: TranspileOpts) -> Result<Transpiled>Expand description
Generate the JS transpilation bindgen for a given Wasm component binary Outputs the file map and import and export metadata for the Transpilation
pub fn transpile(component: &[u8], opts: TranspileOpts) -> Result<Transpiled>Generate the JS transpilation bindgen for a given Wasm component binary Outputs the file map and import and export metadata for the Transpilation