pub enum ErrHandling {
None,
ThrowResultErr,
ResultCatchHandler,
}Expand description
Method of error handling
Variants
None
Do no special handling of errors, requiring users to return objects that represent errors as represented in WIT
ThrowResultErr
Require throwing of result error objects
ResultCatchHandler
Catch thrown errors and convert them into result<t,e> error variants