ComponentStateJsExprsBuilder

Struct ComponentStateJsExprsBuilder 

pub struct ComponentStateJsExprsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ComponentStateJsExprsBuilder<S>

pub fn build(self) -> ComponentStateJsExprs
where S: IsComplete,

Finish building and return the requested object

pub fn component_idx( self, value: String, ) -> ComponentStateJsExprsBuilder<SetComponentIdx<S>>
where S::ComponentIdx: IsUnset,

Required.

JS expression that is a number, e.g. “0”

pub fn callback_fn_name( self, value: String, ) -> ComponentStateJsExprsBuilder<SetCallbackFnName<S>>
where S::CallbackFnName: IsUnset,

Required.

JS expression that is the generated name of the callback, e.g. “callback_1”

pub fn get_callback_fn( self, value: String, ) -> ComponentStateJsExprsBuilder<SetGetCallbackFn<S>>
where S::GetCallbackFn: IsUnset,

Required.

JS function expression that returns the callback function for this function, e.g. “() => callback_1”

pub fn memory_idx( self, value: String, ) -> ComponentStateJsExprsBuilder<SetMemoryIdx<S>>
where S::MemoryIdx: IsUnset,

Required.

JS expression that is the index of the top-level declared memory associated with this function, e.g. “1”

pub fn get_memory_fn( self, value: String, ) -> ComponentStateJsExprsBuilder<SetGetMemoryFn<S>>
where S::GetMemoryFn: IsUnset,

Required.

JS function expression that returns the top-level declared memory associated with this function, e.g. “() => memory0”

pub fn get_realloc_fn( self, value: String, ) -> ComponentStateJsExprsBuilder<SetGetReallocFn<S>>
where S::GetReallocFn: IsUnset,

Required.

JS function expression that returns the realloc fn relevant to this function, e.g. “() => realloc0”