FunctionBindgenBuilder

Struct FunctionBindgenBuilder 

pub struct FunctionBindgenBuilder<'a, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'a, S: State> FunctionBindgenBuilder<'a, S>

pub fn build(self) -> FunctionBindgen<'a>
where S: IsComplete,

Finish building and return the requested object

pub fn resource_map( self, value: &'a ResourceMap, ) -> FunctionBindgenBuilder<'a, SetResourceMap<S>>
where S::ResourceMap: IsUnset,

Required.

Mapping of resources for types that have corresponding definitions locally

pub fn clear_resource_borrows( self, value: bool, ) -> FunctionBindgenBuilder<'a, SetClearResourceBorrows<S>>
where S::ClearResourceBorrows: IsUnset,

Required.

Whether current resource borrows need to be deactivated

pub fn intrinsics( self, value: &'a mut BTreeSet<Intrinsic>, ) -> FunctionBindgenBuilder<'a, SetIntrinsics<S>>
where S::Intrinsics: IsUnset,

Required.

Set of intrinsics

pub fn valid_lifting_optimization( self, value: bool, ) -> FunctionBindgenBuilder<'a, SetValidLiftingOptimization<S>>
where S::ValidLiftingOptimization: IsUnset,

Required.

Whether to perform valid lifting optimization

pub fn sizes( self, value: &'a SizeAlign, ) -> FunctionBindgenBuilder<'a, SetSizes<S>>
where S::Sizes: IsUnset,

Required.

Sizes and alignments for sub elements

pub fn err(self, value: ErrHandling) -> FunctionBindgenBuilder<'a, SetErr<S>>
where S::Err: IsUnset,

Required.

Method of error handling

pub fn tmp(self, value: usize) -> FunctionBindgenBuilder<'a, SetTmp<S>>
where S::Tmp: IsUnset,

Required.

Temporary values

pub fn src(self, value: Source) -> FunctionBindgenBuilder<'a, SetSrc<S>>
where S::Src: IsUnset,

Required.

Source code of the function

pub fn block_storage( self, value: Vec<Source>, ) -> FunctionBindgenBuilder<'a, SetBlockStorage<S>>
where S::BlockStorage: IsUnset,

Required.

Block storage

pub fn blocks( self, value: Vec<(String, Vec<String>)>, ) -> FunctionBindgenBuilder<'a, SetBlocks<S>>
where S::Blocks: IsUnset,

Required.

Blocks of the function

pub fn params( self, value: Vec<String>, ) -> FunctionBindgenBuilder<'a, SetParams<S>>
where S::Params: IsUnset,

Required.

Parameters of the function

pub fn memory( self, value: &'a String, ) -> FunctionBindgenBuilder<'a, SetMemory<S>>
where S::Memory: IsUnset,

Optional (Some / Option setters). Memory variable

pub fn maybe_memory( self, value: Option<&'a String>, ) -> FunctionBindgenBuilder<'a, SetMemory<S>>
where S::Memory: IsUnset,

Optional (Some / Option setters). Memory variable

pub fn realloc( self, value: &'a String, ) -> FunctionBindgenBuilder<'a, SetRealloc<S>>
where S::Realloc: IsUnset,

Optional (Some / Option setters). Realloc function name

pub fn maybe_realloc( self, value: Option<&'a String>, ) -> FunctionBindgenBuilder<'a, SetRealloc<S>>
where S::Realloc: IsUnset,

Optional (Some / Option setters). Realloc function name

pub fn post_return( self, value: &'a String, ) -> FunctionBindgenBuilder<'a, SetPostReturn<S>>
where S::PostReturn: IsUnset,

Optional (Some / Option setters). Post return function name

pub fn maybe_post_return( self, value: Option<&'a String>, ) -> FunctionBindgenBuilder<'a, SetPostReturn<S>>
where S::PostReturn: IsUnset,

Optional (Some / Option setters). Post return function name

pub fn tracing_prefix( self, value: &'a String, ) -> FunctionBindgenBuilder<'a, SetTracingPrefix<S>>
where S::TracingPrefix: IsUnset,

Required.

Prefix to use when printing tracing information

pub fn tracing_enabled( self, value: bool, ) -> FunctionBindgenBuilder<'a, SetTracingEnabled<S>>
where S::TracingEnabled: IsUnset,

Required.

Whether tracing is enabled

pub fn encoding( self, value: StringEncoding, ) -> FunctionBindgenBuilder<'a, SetEncoding<S>>
where S::Encoding: IsUnset,

Required.

Method if string encoding

pub fn callee(self, value: &'a str) -> FunctionBindgenBuilder<'a, SetCallee<S>>
where S::Callee: IsUnset,

Required.

Callee of the function

pub fn callee_resource_dynamic( self, value: bool, ) -> FunctionBindgenBuilder<'a, SetCalleeResourceDynamic<S>>
where S::CalleeResourceDynamic: IsUnset,

Required.

Whether the callee is dynamic (i.e. has multiple operands)

pub fn resolve( self, value: &'a Resolve, ) -> FunctionBindgenBuilder<'a, SetResolve<S>>
where S::Resolve: IsUnset,

Required.

The [wit_bindgen::Resolve] containing extracted WIT information

pub fn requires_async_porcelain( self, value: bool, ) -> FunctionBindgenBuilder<'a, SetRequiresAsyncPorcelain<S>>
where S::RequiresAsyncPorcelain: IsUnset,

Required.

Whether the function requires async porcelain

In the case of an import this likely implies the use of JSPI and in the case of an export this is simply code generation metadata.

pub fn is_async(self, value: bool) -> FunctionBindgenBuilder<'a, SetIsAsync<S>>
where S::IsAsync: IsUnset,

Required.

Whether the function is guest async lifted (i.e. WASI P3)

pub fn iface_name( self, value: &'a str, ) -> FunctionBindgenBuilder<'a, SetIfaceName<S>>
where S::IfaceName: IsUnset,

Optional (Some / Option setters). Interface name

pub fn maybe_iface_name( self, value: Option<&'a str>, ) -> FunctionBindgenBuilder<'a, SetIfaceName<S>>
where S::IfaceName: IsUnset,

Optional (Some / Option setters). Interface name

pub fn asmjs(self, value: bool) -> FunctionBindgenBuilder<'a, SetAsmjs<S>>
where S::Asmjs: IsUnset,

Required.

Whether the callee was transpiled from Wasm to JS (asm.js) and thus needs shimming for i64

pub fn component_state( self, value: FunctionBindgenComponentState, ) -> FunctionBindgenBuilder<'a, SetComponentState<S>>
where S::ComponentState: IsUnset,

Optional (Some / Option setters). Component state generated from processing a component.

This information is normally accessible via producing/having access to a wasmtime_environ::component::Component), and is required for some bindgen instructions.

If you are performing bindgen aganist a dummy module, you may omit this field, but if processing has been performed on the component, and this state is available at time of generation for this function, provide this information (normally found in [CanonicalOptions]s)

pub fn maybe_component_state( self, value: Option<FunctionBindgenComponentState>, ) -> FunctionBindgenBuilder<'a, SetComponentState<S>>
where S::ComponentState: IsUnset,

Optional (Some / Option setters). Component state generated from processing a component.

This information is normally accessible via producing/having access to a wasmtime_environ::component::Component), and is required for some bindgen instructions.

If you are performing bindgen aganist a dummy module, you may omit this field, but if processing has been performed on the component, and this state is available at time of generation for this function, provide this information (normally found in [CanonicalOptions]s)