#[non_exhaustive]pub struct FunctionBindgenComponentState { /* private fields */ }Expand description
Metadata that is derived from processing a component.
This information is often required to perform bindgen completely, but requires component processing which not all downstream bindgen consumers may perform.
For bindgen consumers that perform generation which requires this information, the information should be provided.
Implementations
Sourceimpl FunctionBindgenComponentState
impl FunctionBindgenComponentState
Sourcepub fn builder() -> FunctionBindgenComponentStateBuilder
pub fn builder() -> FunctionBindgenComponentStateBuilder
Create an instance of FunctionBindgenComponentState using the builder syntax