Module intrinsics

Module intrinsics 

Intrinsics used from JS

Structs

RenderIntrinsicsArgs
Arguments to render_intrinsics
RenderIntrinsicsArgsBuilder
Use builder syntax to set the inputs and finish with build().

Enums

AsyncDeterminismProfile
Profile for determinism to be used by async implementation
Intrinsic
List of all intrinsics that are used by these

Functions

render_intrinsics
Emits the intrinsic i to this file and then returns the name of the intrinsic.