pub enum Intrinsic {
Show 59 variants
JsHelper(JsHelperIntrinsic),
WebIdl(WebIdlIntrinsic),
Conversion(ConversionIntrinsic),
String(StringIntrinsic),
Resource(ResourceIntrinsic),
ErrCtx(ErrCtxIntrinsic),
AsyncTask(AsyncTaskIntrinsic),
Waitable(WaitableIntrinsic),
Lift(LiftIntrinsic),
Lower(LowerIntrinsic),
AsyncStream(AsyncStreamIntrinsic),
AsyncFuture(AsyncFutureIntrinsic),
Component(ComponentIntrinsic),
Host(HostIntrinsic),
PromiseWithResolversPonyfill,
DebugLog,
GlobalAsyncDeterminism,
CoinFlip,
ConstantI32Max,
ConstantI32Min,
TypeCheckValidI32,
TypeCheckAsyncFn,
AsyncFunctionCtor,
Base64Compile,
ClampGuest,
FetchCompile,
SymbolCabiDispose,
SymbolCabiLower,
SymbolResourceHandle,
SymbolResourceRep,
SymbolDispose,
SymbolAsyncIterator,
SymbolIterator,
ScopeId,
HandleTables,
PlatformReadableStreamClass,
FinalizationRegistryCreate,
ComponentError,
GetErrorPayload,
GetErrorPayloadString,
ManagedBufferClass,
BufferManagerClass,
GlobalBufferManager,
RepTableClass,
AsyncEventCodeEnum,
IsLE,
ThrowInvalidBool,
ThrowUninitialized,
HasOwnProperty,
InstantiateCore,
GlobalComponentMemoryMap,
RegisterGlobalMemoryForComponent,
LookupMemoriesForComponent,
GlobalCurrentTaskMeta,
GetGlobalCurrentTaskMetaFn,
SetGlobalCurrentTaskMetaFn,
WithGlobalCurrentTaskMetaFn,
WithGlobalCurrentTaskMetaFnAsync,
ClearGlobalCurrentTaskMetaFn,
}Expand description
List of all intrinsics that are used by these
These intrinsics refer to JS code that is included in order to make transpiled WebAssembly components and their imports/exports functional in the relevant JS context.
Variants
JsHelper(JsHelperIntrinsic)
WebIdl(WebIdlIntrinsic)
Conversion(ConversionIntrinsic)
String(StringIntrinsic)
Resource(ResourceIntrinsic)
ErrCtx(ErrCtxIntrinsic)
AsyncTask(AsyncTaskIntrinsic)
Waitable(WaitableIntrinsic)
Lift(LiftIntrinsic)
Lower(LowerIntrinsic)
AsyncStream(AsyncStreamIntrinsic)
AsyncFuture(AsyncFutureIntrinsic)
Component(ComponentIntrinsic)
Host(HostIntrinsic)
PromiseWithResolversPonyfill
DebugLog
Enable debug logging
GlobalAsyncDeterminism
Global setting for determinism (used in async)
CoinFlip
Randomly produce a boolean true/false
ConstantI32Max
ConstantI32Min
TypeCheckValidI32
TypeCheckAsyncFn
AsyncFunctionCtor
Base64Compile
ClampGuest
FetchCompile
SymbolCabiDispose
SymbolCabiLower
SymbolResourceHandle
SymbolResourceRep
SymbolDispose
SymbolAsyncIterator
SymbolIterator
ScopeId
HandleTables
PlatformReadableStreamClass
Class that conforms to a ReadableStreams-like interface and is usable externally
This is normally the ReadableStream class provided by the platform itself.
FinalizationRegistryCreate
ComponentError
GetErrorPayload
GetErrorPayloadString
ManagedBufferClass
Class that manages (and synchronizes) writes to managed buffers
BufferManagerClass
Buffer manager that is used to synchronize component writes
GlobalBufferManager
Global for an instantiated buffer manager singleton
RepTableClass
Reusable table structure for holding canonical ABI objects by their representation/identifier of (e.g. resources, waitables, etc)
Representations of objects stored in one of these tables is a u32 (0 is expected to be an invalid index).
AsyncEventCodeEnum
Event codes used for async, as a JS enum
IsLE
ThrowInvalidBool
ThrowUninitialized
HasOwnProperty
InstantiateCore
GlobalComponentMemoryMap
Tracking of component memories
RegisterGlobalMemoryForComponent
Tracking of component memories
LookupMemoriesForComponent
Tracking of component memories
GlobalCurrentTaskMeta
Global that tracks the current task
GetGlobalCurrentTaskMetaFn
Gets the current global task state
SetGlobalCurrentTaskMetaFn
Gets the current global task state
WithGlobalCurrentTaskMetaFn
Execute a closure with a certain set current task
WithGlobalCurrentTaskMetaFnAsync
Execute an async closure with a certain set current task
ClearGlobalCurrentTaskMetaFn
Clear the global task meta
Implementations
Sourceimpl Intrinsic
impl Intrinsic
pub fn render(&self, output: &mut Source, args: &RenderIntrinsicsArgs<'_>)
Sourceimpl Intrinsic
impl Intrinsic
pub fn get_global_names() -> impl IntoIterator<Item = &'static str>
pub fn name(&self) -> &'static str