TranspileOpts

Struct TranspileOpts 

pub struct TranspileOpts {
Show 16 fields pub name: String, pub no_typescript: bool, pub instantiation: Option<InstantiationMode>, pub import_bindings: Option<BindingsMode>, pub map: Option<HashMap<String, String>>, pub no_nodejs_compat: bool, pub base64_cutoff: usize, pub tla_compat: bool, pub valid_lifting_optimization: bool, pub tracing: bool, pub no_namespaced_exports: bool, pub multi_memory: bool, pub guest: bool, pub async_mode: Option<AsyncMode>, pub strict: bool, pub asmjs: bool,
}

Fields

name: Stringno_typescript: bool

Disables generation of *.d.ts files and instead only generates *.js source files.

instantiation: Option<InstantiationMode>

Provide a custom JS instantiation API for the component instead of the direct importable native ESM output.

import_bindings: Option<BindingsMode>

Configure how import bindings are provided, as high-level JS bindings, or as hybrid optimized bindings.

map: Option<HashMap<String, String>>

Comma-separated list of “from-specifier=./to-specifier.js” mappings of component import specifiers to JS import specifiers.

no_nodejs_compat: bool

Disables compatibility in Node.js without a fetch global.

base64_cutoff: usize

Set the cutoff byte size for base64 inlining core Wasm in instantiation mode (set to 0 to disable all base64 inlining)

tla_compat: bool

Enables compatibility for JS environments without top-level await support via an async $init promise export to wait for instead.

valid_lifting_optimization: bool

Disable verification of component Wasm data structures when lifting as a production optimization

tracing: bool

Whether or not to emit tracing calls on function entry/exit.

no_namespaced_exports: bool

Whether to generate namespaced exports like foo as "local:package/foo". These exports can break typescript builds.

multi_memory: bool

Whether to output core Wasm utilizing multi-memory or to polyfill this handling.

guest: bool

Whether to generate types for a guest module using module declarations.

async_mode: Option<AsyncMode>

Configure whether to use async imports or exports with JavaScript Promise Integration (JSPI).

strict: bool

Configure whether to generate code that includes strict type checks

asmjs: bool

Whether the core module(s) to be wrapped were actually transpiled from Wasm to JS (asm.js) and thus need shimming for i64