Structs
- Function
Bindgen - Payload
Type Metadata - Resource
Table - Map used for resource function bindgen within a given component
Enums
- ErrHandling
- Method of error handling
- Resource
Data - Data related to a given resource
- Resource
Extra Data - Supplemental data kept along with
ResourceData
Functions
- as_
nullable - Tests whether
tycan be represented withnull, and if it can then the “other type” is returned. IfSomeis returned that means thattyisnull | <return>. IfNoneis returned that means thatnullcan’t be used to representty. - js_
array_ ty - Retrieve the specialized JS array type that would contain a given element type, if one exists.
- maybe_
null
Type Aliases
- Resource
Map - A mapping of type IDs to the resources that they represent