Module function_bindgen

Module function_bindgen 

Structs

FunctionBindgen
ResourceTable
Map used for resource function bindgen within a given component

Enums

ErrHandling
Method of error handling
ResourceData
Data related to a given resource
ResourceExtraData
Supplemental data kept along with ResourceData

Functions

as_nullable
Tests whether ty can be represented with null, and if it can then the “other type” is returned. If Some is returned that means that ty is null | <return>. If None is returned that means that null can’t be used to represent ty.
js_array_ty
Retrieve the specialized JS array type that would contain a given element type, if one exists.
maybe_null

Type Aliases

ResourceMap
A mapping of type IDs to the resources that they represent