Module function_bindgen
js_
component_
bindgen
1.16.5
Module function_
bindgen
Module Items
Structs
Enums
Functions
Type Aliases
In crate js_
component_
bindgen
js_component_bindgen
Module
function_
bindgen
Structs

Function
Bindgen
Resource
Table
Map used for resource function bindgen within a given component
Enums

ErrHandling
Method of error handling
Resource
Data
Data related to a given resource
Resource
Extra
Data
Supplemental data kept along with
ResourceData
Functions

as_
nullable
Tests whether
ty
can be represented with
null
, and if it can then the “other type” is returned. If
Some
is returned that means that
ty
is
null | <return>
. If
None
is returned that means that
null
can’t be used to represent
ty
.
js_
array_
ty
Retrieve the specialized JS array type that would contain a given element type, if one exists.
maybe_
null
Type Aliases

Resource
Map
A mapping of type IDs to the resources that they represent