Function js_array_ty
Source pub fn js_array_ty(resolve: &Resolve, element_ty: &Type) -> Option<&'static str>
Retrieve the specialized JS array type that would contain a given element type,
if one exists.
e.g. a Wasm Type::U8 would be represetned by a JS Uint8Array
Arguments
resolve - The Resolve used to look up nested type IDs if necessary
element_ty - The Type that represents elements of the array