pub struct TranspileOpts {Show 16 fields
pub name: String,
pub no_typescript: bool,
pub instantiation_mode: Option<InstantiationMode>,
pub import_bindings: Option<BindingsMode>,
pub map: Option<HashMap<String, String>>,
pub nodejs_compat_disabled: bool,
pub base64_cutoff: usize,
pub tla_compat: bool,
pub valid_lifting_optimization: bool,
pub tracing: bool,
pub no_namespaced_exports: bool,
pub multi_memory: bool,
pub guest: bool,
pub async_mode: Option<AsyncMode>,
pub strict: bool,
pub asmjs: bool,
}Fields
name: Stringno_typescript: boolDisables generation of *.d.ts files and instead only generates *.js
source files.
instantiation_mode: Option<InstantiationMode>Provide a custom JS instantiation API for the component instead of the direct importable native ESM output.
import_bindings: Option<BindingsMode>Configure how import bindings are provided, as high-level JS bindings, or as hybrid optimized bindings.
map: Option<HashMap<String, String>>Comma-separated list of “from-specifier=./to-specifier.js” mappings of component import specifiers to JS import specifiers.
nodejs_compat_disabled: boolDisables compatibility in Node.js without a fetch global.
base64_cutoff: usizeSet the cutoff byte size for base64 inlining core Wasm in instantiation mode (set to 0 to disable all base64 inlining)
tla_compat: boolEnables compatibility for JS environments without top-level await support via an async $init promise export to wait for instead.
valid_lifting_optimization: boolDisable verification of component Wasm data structures when lifting as a production optimization
tracing: boolWhether or not to emit tracing calls on function entry/exit.
no_namespaced_exports: boolWhether to generate namespaced exports like foo as "local:package/foo".
These exports can break typescript builds.
multi_memory: boolWhether to output core Wasm utilizing multi-memory or to polyfill this handling.
guest: boolWhether to generate types for a guest module using module declarations.
async_mode: Option<AsyncMode>Configure whether to use async imports or exports with
JavaScript Promise Integration (JSPI).
strict: boolConfigure whether to generate code that includes strict type checks
asmjs: boolWhether the core module(s) to be wrapped were actually transpiled from Wasm to JS (asm.js) and thus need shimming for i64
Implementations
Sourceimpl TranspileOpts
impl TranspileOpts
Sourcepub fn builder() -> TranspileOptsBuilder
pub fn builder() -> TranspileOptsBuilder
Create an instance of TranspileOpts using the builder syntax